/* simstat.c
 *
 * Request status from a server
 */
#include "sim.h"

int fd_debug = 0;		/* needed by fdio.c */
int is_sim_server = 0;		/* isn't actually used */

int main(int argc, char **argv)
{
int i,fd;
char *pass, *server;
int port = SIM_PORT;
int html = 0;

/* parse command line args
 */
if (argc < 3) {
	logerror("usage : simsstat <password> <server> [port] [-html]");
	exit(1);
	}
pass = argv[1];
server = argv[2];
for(i=3; i<argc; i++) {
	if (strequ(argv[i],"-html"))
		html = 1;
	else
		port = atoi(argv[3]);
	}

if (html) {
	/* Output heading
	 */
	puts("Content-type: text/html");
	puts("");
	printf("<title>Sim server %s status</title>\n",server);
	printf("<h1>Sim server %s status</h1>\n",server);
	}

/* Connect and send request
 */
if ((fd = open_tcp_send(server,port)) == -1) {
	if (html)
		puts("Server is down.<p>");
	else
		logerror("Couldn't connect to %s port %d",server,port);
	exit(2);
	}
if (!send_version(fd))
	exit(3);
fdprintf(fd,"%d\n",con_status);
if (!send_password(fd,pass))
	exit(3);

/* Read player status lines
 */
if (html) {
	puts("<b>Players</b><br>");
	puts("<table border=5 width=100%>");
	puts("<tr> <td><b>Name</b></td> <td><b>Position</b></td> <td><b>Fd</b></td> <td><b>Login/out</b></td> <td><b>Ilevel</b></td> <td><b>Hostname</b></td> </tr>");
	}
else {
	printf("Players on %s\n",server);
	printf("%-14.14s|%-14.14s|%-8.8s|%-15.15s|%-9.9s|%-14.14s\n",
	 "Name","Position","Fd","Login/out","Ilevel","Hostname");
	printf("--------------+--------------+--------+---------------+---------+--------------\n");
	}
while(1) {
	char pline[256];	/* line of player details */
	char **pdv;		/* vector of strings from line */
	int pdc;
	char *prname;		/* person's name */
	char *prpos;		/* person's pos */
	char *prfd;		/* person's fd */
	char prtime[256] = "";	/* person's login/out time */
	char *prhostname = "";	 /* person's hostname */
	char *prilevel = "";	/* perons's 3d level */

	fdgets(fd,pline,256);
	parse_string(pline,&pdv,&pdc);
	if (!pdc) break;		/* end of persons */
	prname = pdv[0];
	prpos  = pdv[1];
	prfd   = pdv[2];
	if (!strequ(prfd,"npc")) {
		time_t tm = atol(pdv[3]);

		strftime(prtime,256,"%H:%M:%S %d/%m",localtime(&tm));
		if (!strequ(prfd,"offline")) {
			struct hostent *hent;
			struct in_addr ip;
			ip.s_addr = strtoul(pdv[4],NULL,10);

			hent = gethostbyaddr((char *)&ip,sizeof(ip),AF_INET);
			prhostname = hent ? hent->h_name : dotted_notation(ip);
			switch(atoi(pdv[5])) {
			case lvl_none: prilevel = "none"; break;
			case lvl_flat: prilevel = "flat"; break;
			case lvl_textured: prilevel = "textured"; break;
			default: prilevel = "unknown";
				}
			}
		}
	if (html)
		printf("<tr> <td><b>%s</b></td> <td><b>%s</b></td> "
		 "<td><b>%s</b></td> <td><b>%s</b></td> <td><b>%s</b></td> "
		 "<td><b>%s</b></td> </tr>\n",prname,prpos,prfd,prtime,
					      prilevel,prhostname);
	else
		printf("%-14.14s|%-14.14s|%-8.8s|%-15.15s|%-9.9s|%-14.14s\n",
		 prname,prpos,prfd,prtime,prilevel,prhostname);
	}

if (html)
	puts("</table>");
close(fd);
}

